@@ -1,5 +1,5 @@
 from .typetwo import TypeTwo
-from .rowkey import RowKey, NoKey
+from .rowkey import RowKey, NoKey, FunKey
 from .dictcomparer import DictComparer
 from .isojson import IsoJson
 from .transformer import Transformer
@@ -8,6 +8,7 @@ __all__ = [
     TypeTwo.__name__, 
     RowKey.__name__, 
     NoKey.__name__, 
+    FunKey.__name__,
     DictComparer.__name__, 
     IsoJson.__name__, 
     Transformer.__name__
